=================
Contributor Guide
=================

This guide is for contributors of the Kolla project. It includes information on
proposing your first patch and how to participate in the community.  It also
covers responsibilities of core reviewers and the Project Team Lead (PTL), and
information about development processes.

We welcome everyone to join our project!

.. toctree::
   :maxdepth: 2

   contributing
   running-in-development
   adding-a-new-image
   genconfig
   release-notes
   running-tests
   code-reviews
   bug-triage
   ptl-guide
   release-management
   ci
